function Y = hps(X, n)
%HPS Harmonic product spectrum
%   Y = HPS(X, N)
%       Produces the harmonic product spectrum Y using the first N
%       decimated spectra of the original spectrum X.
%       X must be a column vector, containing the one-sided magnitude or 
%       power spectrum of the signal, and N must be a positive integer.
%       Y will also be a column vector.
%
%   References:
%       P. de la Cuadra. "HPS Algorithm".
%       https://ccrma.stanford.edu/~pdelac/220c/pitch_detection/img2.htm

n_in = size(X, 1);          % Input size
n_out = floor(n_in / n);    % Output size

Y = X(1 : n_out, :);        % Prepare output

% Assemble product spectrum
for i = 2 : n
    Y = Y .* X(1 : i : (i*n_out), :);
end

end % of function HPS

